==> jetjob_1.6.0.0.tar.gz: jetjob_1.6.0.0/htdocs/common_info.php <==
<?php
//==============================================================
// Program Name		: menu
// File Name		: common_info.php
//--------------------------------------------------------------
// Date 			: 2000/11/29
// Author			: S Fujii
//--------------------------------------------------------------
// Note				: С
//					: 
//--------------------------------------------------------------
// Rev. 			: 
//					: 
//==============================================================


require("jetjob.inc");			// 
require("common_check.inc");	// 
require("common_login.php");		// 


define("VERSION", "1.6");				// С


define("CSS_FILE", $JJ_CSS_ROOT . $JJ_CSS_NAME);			// 륷
define("PAGE_WIDTH", 600);									// ڡ
define("BG_COLOR_1", "#d2e6d9");							// طʿ
define("BG_COLOR_2", "#f7f2e8");							// طʿ
define("LOGO_IMG", $JJ_IMG_ROOT . "logo.gif");				// 
define("SPACE_GIF_FILE", $JJ_IMG_ROOT . "spacer.gif");		// 
define("COPYRIGHT", "Copyright&copy; 2000-2007, Aquaplan Networks All Rights Reserved.<br>Maintenance Team : netnee.,Co Ltd. and Niigata Open Source Software Association");	// ԡ饤


//==============================================================
// Function Name	: Print_Header
//--------------------------------------------------------------
// Note				: 
//					:
//==============================================================
Function Print_Header()
{
	global $JJ_USERNAME, $JJ_PERMISSION;
	global	$JJ_OUTPUT_CHARSET;
	
	print("<HTML><HEAD>\n");
	print("<META http-equiv=\"Content-Language\" content=\"ja\">\n");
	print("<META http-equiv=\"Content-Type\" content=\"text/html; charset=$JJ_OUTPUT_CHARSET\">\n");
	print("<LINK REL=STYLESHEET TYPE=\"text/css\" HREF=\"" . CSS_FILE . "\">\n");
	print("</HEAD>\n");
	print("<BODY>\n");
}


//==============================================================
// Function Name	: Print_Footer
//--------------------------------------------------------------
// Note				: 
//					:
//==============================================================
Function Print_Footer()
{
	print("</BODY>\n");
	print("</HTML>\n");
}


//==============================================================
// Function Name	: Print_Index
//--------------------------------------------------------------
// Note				: ɽե
//					:
//==============================================================
Function Print_Index()
{
	global	$JJ_USE_DATABASE;
	global	$JJ_DOCS_ROOT, $JJ_DIR_NAME;
	global 	$JJ_CSS_ROOT_FULL, $JJ_IMG_ROOT_FULL, $JJ_INC_ROOT_FULL, $JJ_TMP_ROOT_FULL, 
			$JJ_MAIL_ROOT_FULL, $JJ_BBS_ROOT_FULL, $JJ_MEMBER_ROOT_FULL, 
			$JJ_WORKFLOW_ROOT_FULL, $JJ_TEMPLATE_ROOT_FULL;
	global	$JJ_USERNAME, $JJ_PERMISSION;
	
	// ǡ١
	$db = new DB_Test;
	$host_name = $db->Host;
	$db_name = $db->Database;
	
	// 
	if ($JJ_PERMISSION == "admin")
		$perm = "";
	else
		$perm = "̥桼";
	
	// ȥʬ
	printf("<table border=\"0\" cellpadding=\"5\" cellspacing=\"0\" width=\"%d\">\n",
		PAGE_WIDTH);
	print("<tr align=\"center\">\n");
	print("<td class=\"color00\" width=\"50%\"><b>JET-JOB С</b></td>\n");
	print("<td width=\"50%\" bgcolor=\"#cccccc\"><br></td>\n");
	print("</tr>\n");
	print("<tr>\n");
	printf("<td colspan=\"2\" class=\"color00\"><img src=\"%s\"></td>\n", SPACE_GIF_FILE);
	print("</tr>\n");
	print("<tr><td colspan=\"2\" bgcolor=\"white\" valign=\"top\">\n");
	
	// ʬ
	printf("<table border=\"0\" cellpadding=\"5\" cellspacing=\"3\" width=\"100%%\" bgcolor=\"%s\">\n",
		BG_COLOR_2);
	print("<tr><td align=\"center\" colspan=\"2\">\n");
	printf("<img src=\"%s\" border=\"0\">\n", LOGO_IMG);
	printf("<font size=\"+1\">Ver %s</font>\n", VERSION);
	print("</td></tr>\n");
	printf("<tr><td align=\"right\">%s</td></tr>\n", COPYRIGHT);
	print("</table>\n");

/****
	print("<br>\n");
	
	print("<table border=\"0\" cellpadding=\"5\" cellspacing=\"3\" width=\"100%%\">\n");

	print("<tr align=\"center\" class=\"color01\">\n");
	print("<td colspan=\"2\"><b>ǡ١Ϣ</b></td>\n");
	print("</tr>\n");
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>ѥǡ١</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_USE_DATABASE);
	print("</tr>\n");
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>ۥ̾</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $host_name);
	print("</tr>\n");
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>ǡ١̾</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $db_name);
	print("</tr>\n");
	
	print("<tr><td colspan=\"2\"><br></td></tr>\n");
	
	print("<tr align=\"center\" class=\"color01\">\n");
	print("<td colspan=\"2\"><b>եϢ</b></td>\n");
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>ƥե</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_DOCS_ROOT . $JJ_DIR_NAME);
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>륷ȥե</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_CSS_ROOT_FULL);
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>᡼եե</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_IMG_ROOT_FULL);
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>󥯥롼ɥեե</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_INC_ROOT_FULL);
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>ƥݥեե</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_TMP_ROOT_FULL);
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>᡼ѥեե</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_MAIL_ROOT_FULL);
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>Ǽĥեե</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_BBS_ROOT_FULL);
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>Сեե</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_MEMBER_ROOT_FULL);
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>եѥեե</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_WORKFLOW_ROOT_FULL);
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>եѥեե</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_TEMPLATE_ROOT_FULL);
	print("</tr>\n");
	
	print("<tr><td colspan=\"2\"><br></td></tr>\n");
	
	print("<tr align=\"center\" class=\"color01\">\n");
	print("<td colspan=\"2\"><b>ߤΥ桼</b></td>\n");
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>̾</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_USERNAME);
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>桼</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $perm);
	print("</tr>\n");

	print("</table>");
***/
	print("</td></tr></table>\n");

	//phpinfo();



}

//==============================================================
// Function Name	: Program_Start
//--------------------------------------------------------------
// Note				: 
//					:
//==============================================================
Login_Start(PG_NAME());

//Init_set();

Print_Header();
/*
switch ($mode) {
	case "UPD" ://UPDATE
		Tbl_upd();
		Print_Index();
		break;
	default ://ɽ
		Print_Index();
}
*/
Print_Index();
Print_Footer();
?>

==> jetjob_1.6.0.3.tar.gz: jetjob_1.6.0.3/htdocs/common_info.php <==
<?php
//==============================================================
// Program Name		: menu
// File Name		: common_info.php
//--------------------------------------------------------------
// Date 			: 2000/11/29
// Author			: S Fujii
//--------------------------------------------------------------
// Note				: С
//					: 
//--------------------------------------------------------------
// Rev. 			: 
//					: 
//==============================================================


require("jetjob.inc.php");
require("common_check.inc");		// 
require("common_login.php");		// 


define("VERSION", "1.6.0.3");		// С


define("CSS_FILE", $JJ_CSS_ROOT . $JJ_CSS_NAME);			// 륷
define("PAGE_WIDTH", 600);									// ڡ
define("BG_COLOR_1", "#d2e6d9");							// طʿ
define("BG_COLOR_2", "#f7f2e8");							// طʿ
define("LOGO_IMG", $JJ_IMG_ROOT . "logo.gif");				// 
define("SPACE_GIF_FILE", $JJ_IMG_ROOT . "spacer.gif");		// 
define("COPYRIGHT", "Copyright&copy; 2000-2007, Aquaplan Networks All Rights Reserved.<br>Maintenance Team : netnee.,Co Ltd. and Niigata Open Source Software Association");	// ԡ饤


//==============================================================
// Function Name	: Print_Header
//--------------------------------------------------------------
// Note				: 
//					:
//==============================================================
Function Print_Header()
{
	global $JJ_USERNAME, $JJ_PERMISSION;
	global	$JJ_OUTPUT_CHARSET;
	
	print("<HTML><HEAD>\n");
	print("<META http-equiv=\"Content-Language\" content=\"ja\">\n");
	print("<META http-equiv=\"Content-Type\" content=\"text/html; charset=$JJ_OUTPUT_CHARSET\">\n");
	print("<LINK REL=STYLESHEET TYPE=\"text/css\" HREF=\"" . CSS_FILE . "\">\n");
	print("</HEAD>\n");
	print("<BODY>\n");
}


//==============================================================
// Function Name	: Print_Footer
//--------------------------------------------------------------
// Note				: 
//					:
//==============================================================
Function Print_Footer()
{
	print("</BODY>\n");
	print("</HTML>\n");
}


//==============================================================
// Function Name	: Print_Index
//--------------------------------------------------------------
// Note				: ɽե
//					:
//==============================================================
Function Print_Index()
{
	global	$JJ_USE_DATABASE;
	global	$JJ_DOCS_ROOT, $JJ_DIR_NAME;
	global 	$JJ_CSS_ROOT_FULL, $JJ_IMG_ROOT_FULL, $JJ_INC_ROOT_FULL, $JJ_TMP_ROOT_FULL, 
			$JJ_MAIL_ROOT_FULL, $JJ_BBS_ROOT_FULL, $JJ_MEMBER_ROOT_FULL, 
			$JJ_WORKFLOW_ROOT_FULL, $JJ_TEMPLATE_ROOT_FULL;
	global	$JJ_USERNAME, $JJ_PERMISSION;
	
	// ǡ١
	$db = new DB_Test;
	$host_name = $db->Host;
	$db_name = $db->Database;
	
	// 
	if ($JJ_PERMISSION == "admin")
		$perm = "";
	else
		$perm = "̥桼";
	
	// ȥʬ
	printf("<table border=\"0\" cellpadding=\"5\" cellspacing=\"0\" width=\"%d\">\n",
		PAGE_WIDTH);
	print("<tr align=\"center\">\n");
	print("<td class=\"color00\" width=\"50%\"><b>JET-JOB С</b></td>\n");
	print("<td width=\"50%\" bgcolor=\"#cccccc\"><br></td>\n");
	print("</tr>\n");
	print("<tr>\n");
	printf("<td colspan=\"2\" class=\"color00\"><img src=\"%s\"></td>\n", SPACE_GIF_FILE);
	print("</tr>\n");
	print("<tr><td colspan=\"2\" bgcolor=\"white\" valign=\"top\">\n");
	
	// ʬ
	printf("<table border=\"0\" cellpadding=\"5\" cellspacing=\"3\" width=\"100%%\" bgcolor=\"%s\">\n",
		BG_COLOR_2);
	print("<tr><td align=\"center\" colspan=\"2\">\n");
	printf("<img src=\"%s\" border=\"0\">\n", LOGO_IMG);
	printf("<font size=\"+1\">Ver %s</font>\n", VERSION);
	print("</td></tr>\n");
	printf("<tr><td align=\"right\">%s</td></tr>\n", COPYRIGHT);
	print("</table>\n");

/****
	print("<br>\n");
	
	print("<table border=\"0\" cellpadding=\"5\" cellspacing=\"3\" width=\"100%%\">\n");

	print("<tr align=\"center\" class=\"color01\">\n");
	print("<td colspan=\"2\"><b>ǡ١Ϣ</b></td>\n");
	print("</tr>\n");
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>ѥǡ١</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_USE_DATABASE);
	print("</tr>\n");
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>ۥ̾</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $host_name);
	print("</tr>\n");
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>ǡ١̾</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $db_name);
	print("</tr>\n");
	
	print("<tr><td colspan=\"2\"><br></td></tr>\n");
	
	print("<tr align=\"center\" class=\"color01\">\n");
	print("<td colspan=\"2\"><b>եϢ</b></td>\n");
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>ƥե</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_DOCS_ROOT . $JJ_DIR_NAME);
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>륷ȥե</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_CSS_ROOT_FULL);
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>᡼եե</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_IMG_ROOT_FULL);
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>󥯥롼ɥեե</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_INC_ROOT_FULL);
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>ƥݥեե</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_TMP_ROOT_FULL);
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>᡼ѥեե</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_MAIL_ROOT_FULL);
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>Ǽĥեե</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_BBS_ROOT_FULL);
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>Сեե</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_MEMBER_ROOT_FULL);
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>եѥեե</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_WORKFLOW_ROOT_FULL);
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>եѥեե</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_TEMPLATE_ROOT_FULL);
	print("</tr>\n");
	
	print("<tr><td colspan=\"2\"><br></td></tr>\n");
	
	print("<tr align=\"center\" class=\"color01\">\n");
	print("<td colspan=\"2\"><b>ߤΥ桼</b></td>\n");
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>̾</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $JJ_USERNAME);
	print("</tr>\n");
	
	print("<tr>\n");
	print("<td class=\"color02\" width=\"40%\"><b>桼</b></td>\n");
	printf("<td bgcolor=\"#f7f2e8\">%s</td>\n", $perm);
	print("</tr>\n");

	print("</table>");
***/
	print("</td></tr></table>\n");

	//phpinfo();



}

//==============================================================
// Function Name	: Program_Start
//--------------------------------------------------------------
// Note				: 
//					:
//==============================================================
Login_Start(PG_NAME());

//Init_set();

Print_Header();
/*
switch ($mode) {
	case "UPD" ://UPDATE
		Tbl_upd();
		Print_Index();
		break;
	default ://ɽ
		Print_Index();
}
*/
Print_Index();
Print_Footer();
?>
